#! /usr/bin/env python
# -*- coding: utf-8 -*-

import argparse
import datetime
import logging
import os
import shutil
import tempfile

from resworb.browsers.safari import Safari

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)


def parse_args():
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter
    )
    parser.add_argument(
        "--source",
        type=str,
        choices=["cloud_tabs", "opened_tabs", "histories", "bookmarks", "readings"],
        default=["cloud_tabs", "readings"],
    )
    parser.add_argument(
        "--inbox",
        type=str,
        default=f"{os.getenv('HOME')}/org/agenda/inbox.org",
    )

    return parser.parse_args()  # pylint: disable=redefined-outer-name


def format_org_heading(url_item, template="* [[{url}][{title}]]\n[{timestamp}]\n"):
    return template.format(
        url=url_item["url"],
        title=url_item["title"],
        timestamp=datetime.datetime.now().strftime("%Y-%m-%d %a %H:%M"),
    )


def format_captures(data):
    def _iter(data):
        for source, source_data in data.items():
            if source == "cloud_tabs":
                for device_data in source_data:
                    yield from device_data["tabs"]
            else:
                yield from source_data

    return map(format_org_heading, _iter(data))


def write_to_inbox(captures, inbox_file):
    with open(inbox_file, mode="r") as f:
        with tempfile.NamedTemporaryFile(mode="w", delete=False) as g:
            wrote = False
            for line in f:
                line = line.rstrip()

                if not wrote and line.startswith("*"):
                    for item in captures:
                        g.writelines(f"{item}\n")
                    wrote = True

                g.writelines(f"{line}\n")
        shutil.copy(g.name, inbox_file)


def main():
    args = parse_args()

    safari = Safari()
    data = safari.export(args.source)

    captures = format_captures(data)
    write_to_inbox(captures, args.inbox)

    logger.info("Export statistics:")
    for source, source_data in data.items():
        if source == "cloud_tabs":
            logger.info("%s\t%d", source, sum(len(x["tabs"]) for x in source_data))
        else:
            logger.info("%s\t%d", source, len(source_data))


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import subprocess
import sys
from pathlib import Path

import pytoml


def filter_packages(data):
    return {
        key for key, value in data.items() if key != "python" and isinstance(value, str)
    }


def update_packages(packages, project_root, dev=False):
    if packages:
        packages = ["{p}@latest".format(p=p) for p in packages]
        command = ["poetry", "add"] + packages
        if dev:
            command += ["--dev"]
        command += ["-vvv"]
        subprocess.run(command, cwd=project_root, check=True)


def main():
    project_root = Path(sys.argv[1]).expanduser().absolute()
    with open(project_root / "pyproject.toml") as f:
        data = pytoml.load(f)

    packages = filter_packages(data["tool"]["poetry"].get("dependencies", []))
    dev_packages = filter_packages(data["tool"]["poetry"].get("dev-dependencies", []))

    update_packages(packages, project_root, dev=False)
    update_packages(dev_packages, project_root, dev=True)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from subprocess import call

from pip._internal.utils.misc import get_installed_distributions

for dist in get_installed_distributions():
    call("pip install --upgrade " + dist.project_name, shell=True)
